@@ -34,6 +34,10 @@
     limitations under the License.
 """
 
+from __future__ import division
+
+from past.builtins import basestring
+from builtins import str
 
 import datetime
 import codecs
@@ -53,7 +57,7 @@ from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
 
 # Constants for identifying the table columns when the WaypointsTableModel is
 # used with a QTableWidget.
-LOCATION, LAT, LON, FLIGHTLEVEL, PRESSURE = range(5)
+LOCATION, LAT, LON, FLIGHTLEVEL, PRESSURE = list(range(5))
 
 
 def seconds_to_string(seconds):
@@ -70,7 +74,7 @@ TABLE_FULL = [
     ("Lat\n(+-90)", lambda waypoint: waypoint.lat, True),
     ("Lon\n(+-180)", lambda waypoint: waypoint.lon, True),
     ("Flightlevel", lambda waypoint: waypoint.flightlevel, True),
-    ("Pressure\n(hPa)", lambda waypoint: "{:.2f}".format(waypoint.pressure / 100.), True),
+    ("Pressure\n(hPa)", lambda waypoint: "{:.2f}".format((waypoint.pressure / 100.)), True),
     ("Leg dist.\n(km [nm])", lambda waypoint: "{:d} [{:d}]".format(
         int(waypoint.distance_to_prev), int(waypoint.distance_to_prev / 1.852)), False),
     ("Cum. dist.\n(km [nm])", lambda waypoint: "{:d} [{:d}]".format(
@@ -94,7 +98,7 @@ class Waypoint(object):
     def __init__(self, lat=0, lon=0, flightlevel=0, location="", comments=""):
         self.location = location
         locations = config_loader(dataset='locations', default=mss_default.locations)
-        if location in locations.keys():
+        if location in locations:
             self.lat, self.lon = locations[location]
         else:
             self.lat = lat
@@ -246,10 +250,9 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
 
         Returns lats, lons.
         """
-        path = [[wp.lat, wp.lon] for wp in self.waypoints]
-        lats, lons = utils.path_points(
+        path = [[wp.lat, wp.lon, wp.utc_time] for wp in self.waypoints]
+        return utils.path_points(
             path, numpoints=numpoints, connection=connection)
-        return lats, lons
 
     def headerData(self, section, orientation, role=QtCore.Qt.DisplayRole):
         """Return data describing the table header; overrides the
@@ -297,6 +300,8 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 waypoint.location = value
             elif column == LAT:
                 try:
+                    # The table fields accept basically any input.
+                    # If the string cannot be converted to "float" (raises ValueError), the user input is discarded.
                     value = float(value)
                 except ValueError:
                     pass
@@ -318,6 +323,8 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                     index2 = self.createIndex(index.row(), LOCATION)
             elif column == LON:
                 try:
+                    # The table fields accept basically any input.
+                    # If the string cannot be converted to "float" (raises ValueError), the user input is discarded.
                     value = float(value)
                 except ValueError:
                     pass
@@ -333,6 +340,8 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                     index2 = self.createIndex(index.row(), LOCATION)
             elif column == FLIGHTLEVEL:
                 try:
+                    # The table fields accept basically any input.
+                    # If the string cannot be converted to "float" (raises ValueError), the user input is discarded.
                     flightlevel = float(value)
                     pressure = thermolib.flightlevel2pressure(flightlevel)
                 except ValueError:
@@ -347,6 +356,8 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                     index2 = self.createIndex(index.row(), PRESSURE)
             elif column == PRESSURE:
                 try:
+                    # The table fields accept basically any input.
+                    # If the string cannot be converted to "float" (raises ValueError), the user input is discarded.
                     pressure = float(value) * 100  # convert hPa to Pa
                     if pressure > 200000:
                         raise ValueError
@@ -496,7 +507,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
             self.waypoints[0].distance_to_prev = 0
             self.waypoints[0].distance_total = 0
         for i in range(1, len(self.waypoints)):
-            wp_comm = unicode(self.waypoints[i].comments)
+            wp_comm = str(self.waypoints[i].comments)
             if len(wp_comm) == 9 and wp_comm.startswith("Hexagon "):
                 wp_comm = "Hexagon {:d}".format(8 - int(wp_comm[-1]))
                 self.waypoints[i].comments = QString(wp_comm)
@@ -540,12 +551,12 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
         for wp in self.waypoints:
             element = doc.createElement("Waypoint")
             wp_el.appendChild(element)
-            element.setAttribute("location", unicode(wp.location))
+            element.setAttribute("location", str(wp.location))
             element.setAttribute("lat", str(wp.lat))
             element.setAttribute("lon", str(wp.lon))
             element.setAttribute("flightlevel", str(wp.flightlevel))
             comments = doc.createElement("Comments")
-            comments.appendChild(doc.createTextNode(unicode(wp.comments)))
+            comments.appendChild(doc.createTextNode(str(wp.comments)))
             element.appendChild(comments)
 
         with codecs.open(self.filename, 'w', encoding="utf-8") as file_object:
@@ -573,7 +584,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
             if len(comments.childNodes):
                 comments = comments.childNodes[0].data.strip()
             else:
-                comments = unicode('')
+                comments = str('')
 
             waypoints_list.append(Waypoint(lat, lon, flightlevel,
                                            location=location,
@@ -603,7 +614,7 @@ class WaypointDelegate(QtWidgets.QItemDelegate):
            waypoints generated by the flight performance service) in red.
         """
         wpnumber_minor = index.model().waypointData(index.row()).wpnumber_minor
-        if wpnumber_minor > 0:
+        if wpnumber_minor is not None and wpnumber_minor > 0:
             newpalette = QtGui.QPalette(option.palette)
             colour = QtGui.QColor(170, 0, 0)  # dark red
             newpalette.setColor(QtGui.QPalette.Text, colour)
@@ -619,14 +630,13 @@ class WaypointDelegate(QtWidgets.QItemDelegate):
         if index.column() == LOCATION:
             combobox = QtWidgets.QComboBox(parent)
             locations = config_loader(dataset='locations', default=mss_default.locations)
-            adds = locations.keys()
+            adds = list(locations.keys())
             if self.parent() is not None:
                 for loc in [wp.location for wp in self.parent().waypoints_model.allWaypointData() if
                             wp.location != ""]:
                     if loc not in adds:
                         adds.append(loc)
-                adds = sorted(adds)
-            combobox.addItems(adds)
+            combobox.addItems(sorted(adds))
 
             combobox.setEditable(True)
             return combobox
@@ -652,9 +662,9 @@ class WaypointDelegate(QtWidgets.QItemDelegate):
            combobox, get the corresponding coordinates.
         """
         if index.column() == LOCATION:
-            loc = unicode(editor.currentText())
+            loc = str(editor.currentText())
             locations = config_loader(dataset='locations', default=mss_default.locations)
-            if loc in locations.keys():
+            if loc in locations:
                 lat, lon = locations[loc]
                 # Don't update distances and flight performance twice, hence
                 # set update=False for LAT.
