@@ -32,6 +32,9 @@
     limitations under the License.
 """
 
+from __future__ import division
+
+from builtins import str
 
 import logging
 
@@ -81,8 +84,8 @@ class MapCanvas(basemap.Basemap):
                               "draw_coastlines": True,
                               "fill_waterbodies": True,
                               "fill_continents": True,
-                              "colour_water": (153 / 255., 255 / 255., 255 / 255., 255 / 255.),
-                              "colour_land": (204 / 255., 153 / 255., 102 / 255., 255 / 255.)}
+                              "colour_water": ((153 / 255.), (255 / 255.), (255 / 255.), (255 / 255.)),
+                              "colour_land": ((204 / 255.), (153 / 255.), (102 / 255.), (255 / 255.))}
         default_appearance.update(param_appearance)
         self.appearance = default_appearance
 
@@ -135,7 +138,7 @@ class MapCanvas(basemap.Basemap):
         if self.appearance["draw_graticule"]:
             try:
                 self._draw_auto_graticule()
-            except Exception, ex:
+            except Exception as ex:
                 logging.error(u"ERROR: cannot plot graticule (message: {} - '{}')".format(type(ex), ex))
         else:
             self.map_parallels = None
@@ -180,18 +183,14 @@ class MapCanvas(basemap.Basemap):
         # Compute some map coordinates that are required below for the automatic
         # determination of which meridians and parallels to draw.
         axis = self.ax.axis()
-        upperLeftCornerLon, upperLeftCornerLat = self.__call__(axis[0],
-                                                               axis[3],
-                                                               inverse=True)
-        lowerRightCornerLon, lowerRightCornerLat = self.__call__(axis[1],
-                                                                 axis[2],
-                                                                 inverse=True)
-        middleUpperBoundaryLon, middleUpperBoundaryLat = \
-            self.__call__(np.mean([axis[0], axis[1]]),
-                          axis[3], inverse=True)
-        middleLowerBoundaryLon, middleLowerBoundaryLat = \
-            self.__call__(np.mean([axis[0], axis[1]]),
-                          axis[2], inverse=True)
+        upperLeftCornerLon, upperLeftCornerLat = self.__call__(
+            axis[0], axis[3], inverse=True)
+        lowerRightCornerLon, lowerRightCornerLat = self.__call__(
+            axis[1], axis[2], inverse=True)
+        middleUpperBoundaryLon, middleUpperBoundaryLat = self.__call__(
+            np.mean([axis[0], axis[1]]), axis[3], inverse=True)
+        middleLowerBoundaryLon, middleLowerBoundaryLat = self.__call__(
+            np.mean([axis[0], axis[1]]), axis[2], inverse=True)
 
         # Determine which parallels and meridians should be drawn.
         #   a) determine which are the minimum and maximum visible
@@ -201,9 +200,8 @@ class MapCanvas(basemap.Basemap):
             # For stereographic projections: Draw meridians from the minimum
             # longitude contained in the map at one of the four corners to the
             # maximum longitude at one of these corner points. If
-            # the map centre is contained in the map, draw all meridians
-            # around the globe.
-            # FIXME? This is only correct for polar stereographic projections.
+            # the southern or norther pole  is contained in the map, draw all
+            # meridians around the globe.
             # Draw parallels from the min latitude contained in the map at
             # one of the four corners OR the middle top or bottom to the
             # maximum latitude at one of these six points.
@@ -215,9 +213,23 @@ class MapCanvas(basemap.Basemap):
             # use projection coordinates for this test
             centre_x = self.projparams["x_0"]
             centre_y = self.projparams["y_0"]
-            contains_centre = (centre_x < self.urcrnrx)and (centre_y < self.urcrnry)
+            centre_lon, centre_lat = self.__call__(centre_x, centre_y, inverse=True)
+            if centre_lat > 0:
+                pole_lon, pole_lat = 0, 90
+            else:
+                pole_lon, pole_lat = 0, -90
+            pole_x, pole_y = self.__call__(pole_lon, pole_lat)
+            if self.urcrnrx > self.llcrnrx:
+                contains_pole = (self.llcrnrx <= pole_x <= self.urcrnrx)
+            else:
+                contains_pole = (self.llcrnrx >= pole_x >= self.urcrnrx)
+            if self.urcrnry > self.llcrnry:
+                contains_pole = contains_pole and (self.llcrnry <= pole_y <= self.urcrnry)
+            else:
+                contains_pole = contains_pole and (self.llcrnry >= pole_y >= self.urcrnry)
+
             # merdidians
-            if contains_centre:
+            if contains_pole:
                 mapLonStart = -180.
                 mapLonStop = 180.
             else:
@@ -234,7 +246,7 @@ class MapCanvas(basemap.Basemap):
                              self.llcrnrlat,
                              middleUpperBoundaryLat, upperLeftCornerLat,
                              self.urcrnrlat)
-            if contains_centre:
+            if contains_pole:
                 centre_lat = self.projparams["lat_0"]
                 mapLatStart = min(mapLatStart, centre_lat)
                 mapLatStop = max(mapLatStop, centre_lat)
@@ -256,17 +268,17 @@ class MapCanvas(basemap.Basemap):
         spacingValues = [0.05, 0.1, 0.25, 0.5, 1, 2, 5, 10, 20, 30, 40]
         deltaLon = mapLonStop - mapLonStart
         deltaLat = mapLatStop - mapLatStart
-        spacingLon = [i for i in spacingValues if i > deltaLon / 11.][0]
-        spacingLat = [i for i in spacingValues if i > deltaLat / 11.][0]
+        spacingLon = [i for i in spacingValues if i > (deltaLon / 11.)][0]
+        spacingLat = [i for i in spacingValues if i > (deltaLat / 11.)][0]
 
         #   c) parallels and meridians start at the first value in the
         #      spacingLon/Lat grid that's smaller than the lon/lat of the
         #      lower left corner; they stop at the first values in the
         #      grid that's larger than the lon/lat of the upper right corner.
-        lonStart = np.floor(mapLonStart / spacingLon) * spacingLon
-        lonStop = np.ceil(mapLonStop / spacingLon) * spacingLon
-        latStart = np.floor(mapLatStart / spacingLat) * spacingLat
-        latStop = np.ceil(mapLatStop / spacingLat) * spacingLat
+        lonStart = np.floor((mapLonStart / spacingLon)) * spacingLon
+        lonStop = np.ceil((mapLonStop / spacingLon)) * spacingLon
+        latStart = np.floor((mapLatStart / spacingLat)) * spacingLat
+        latStop = np.ceil((mapLatStop / spacingLat)) * spacingLat
 
         #   d) call the basemap methods to draw the lines in the determined
         #      range.
@@ -297,12 +309,12 @@ class MapCanvas(basemap.Basemap):
             # If visible if False, remove current graticule if one exists.
             # Every item in self.map_parallels and self.map_meridians is
             # a tuple of a list of lines and a list of text labels.
-            for item in self.map_parallels.values():
+            for item in list(self.map_parallels.values()):
                 for line in item[0]:
                     line.remove()
                 for text in item[1]:
                     text.remove()
-            for item in self.map_meridians.values():
+            for item in list(self.map_meridians.values()):
                 for line in item[0]:
                     line.remove()
                 for text in item[1]:
@@ -440,6 +452,7 @@ class MapCanvas(basemap.Basemap):
         # the backgorund colour).
         if self.map_boundary is not None:
             try:
+                # TODO: review
                 # FIX (mr, 15Oct2012) -- something seems to have changed in
                 # newer Matplotlib versions: this causes an exception when
                 # the user zooms/pans..
@@ -689,7 +702,8 @@ class MapCanvas(basemap.Basemap):
                                                               u"instance::{}".format(self.identifier))
                         for instance in instances:
                             instance.remove()
-                    except (KeyError, ValueError):
+                    except (KeyError, ValueError) as error:
+                        logging.debug("KeyError, ValueError Exception %s", error)
                         pass
                     # Plot new instances.
                     plot_instance = self.plot(x, y,
@@ -710,7 +724,8 @@ class MapCanvas(basemap.Basemap):
                                                                      u"instance::{}".format(self.identifier))
                     plt.setp(old_scatter_instance, visible=False)
                     old_scatter_instance.remove()
-                except (KeyError, ValueError):
+                except (KeyError, ValueError) as error:
+                    logging.debug("KeyError, ValueError Exception %s", error)
                     pass
                 imarker = item.getTimeMarkerIndexes()
                 if imarker is not None:
@@ -770,6 +785,25 @@ class MapCanvas(basemap.Basemap):
             # lon2 ... I cannot figure out why, maybe this is an issue in certain versions
             # of pyproj?? (mr, 16Oct2012)
             lonlats = gc.npts(lons[i], lats[i], lons[i + 1], lats[i + 1], npoints)
+            # The cylindrical projection of matplotlib is not periodic, that means that
+            # -170 longitude and 190 longitude are not identical. The gc projection however
+            # assumes identity and maps all longitudes to -180 to 180. This is no issue for
+            # most other projections.
+            # The clean solution would be to have a periodic display, where the locations
+            # and path are plotted periodically every 360 degree. As long as this is not
+            # supported by matplotlib.basemap, we "hack" this to map the path to the
+            # longitude range defined by the locations. This breaks potentially down in case
+            # that the locations are too far apart (>180 degree), but this is not the typical
+            # use case and will thus hopefully not pose a problem.
+            if self.projection == "cyl":
+                lonlats = np.asarray(lonlats)
+                milon = min(lons[i], lons[i + 1])
+                malon = max(lons[i], lons[i + 1])
+                sel = lonlats[:, 0] < milon
+                lonlats[sel, 0] += 360
+                sel = lonlats[:, 0] > malon
+                lonlats[sel, 0] -= 360
+
             for lon, lat in lonlats:
                 gclons.append(lon)
                 gclats.append(lat)
@@ -834,7 +868,7 @@ class SatelliteOverpassPatch(object):
             pathdata.append((Path.LINETO, self.map(point[0], point[1])))
         for point in sw_r[::-1]:
             pathdata.append((Path.LINETO, self.map(point[0], point[1])))
-        codes, verts = zip(*pathdata)
+        codes, verts = list(zip(*pathdata))
         path = mpl_pi.PathH(verts, codes, map=self.map)
         patch = mpatches.PathPatch(path, facecolor='yellow',
                                    edgecolor='yellow', alpha=0.4)
@@ -878,7 +912,7 @@ class SatelliteOverpassPatch(object):
             # the plots look fine nevertheless.
             try:
                 element.remove()
-            except Exception, ex:
+            except Exception as ex:
                 logging.error("Wildcard exception caught: %s %s", type(ex), ex)
 
 
@@ -956,7 +990,7 @@ class KMLPatch(object):
     def parse_placemarks(self, level):
         for placemark in getattr(level, "Placemark", []):
             name = getattr(placemark, "name", None)
-            style = unicode(getattr(placemark, "styleUrl", ""))
+            style = str(getattr(placemark, "styleUrl", ""))
             logging.debug("Placemark: %s %s", style, name)
             self.parse_geometries(placemark, style, name)
         for folder in getattr(level, "Folder", []):
@@ -966,13 +1000,13 @@ class KMLPatch(object):
 
     def get_style_params(self, style):
         result = {
-            "color": unicode(getattr(style, "color", "")),
+            "color": str(getattr(style, "color", "")),
             "linewidth": float(getattr(style, "width", self.linewidth))
         }
         if not result["color"] or len(result["color"]) != 8:
             result["color"] = self.color
         else:
-            result["color"] = [int(result["color"][i:i + 2], 16) / 255. for i in range(0, 8, 2)]
+            result["color"] = [(int(result["color"][i:i + 2], 16) / 255.) for i in range(0, 8, 2)]
         return result
 
     def parse_styles(self, level):
