@@ -25,6 +25,7 @@
     limitations under the License.
 """
 
+from builtins import str
 
 from mslib.msui.mss_qt import QtCore, QtWidgets, USE_PYQT5
 
@@ -90,7 +91,7 @@ class MSS_PerformanceSettingsDialog(QtWidgets.QDialog, ui_ps.Ui_PerformanceSetti
         """
         filename = QtWidgets.QFileDialog.getOpenFileName(
             self, "Open Aircraft Performance JSON File", constants.MSS_CONFIG_PATH, "(*.json)")
-        filename = filename[0] if USE_PYQT5 else unicode(filename)
+        filename = filename[0] if isinstance(filename, list) and USE_PYQT5 else str(filename)
 
         try:
             performance = config_loader(config_file=filename)
@@ -99,9 +100,9 @@ class MSS_PerformanceSettingsDialog(QtWidgets.QDialog, ui_ps.Ui_PerformanceSetti
             self.dsbTakeoffWeight.setValue(self.aircraft.takeoff_weight)
             self.dsbFuel.setValue(self.aircraft.fuel)
 
-        except KeyError, ex:
+        except KeyError as ex:
             QtWidgets.QMessageBox.critical(self, self.tr("Performance JSON Load"),
                                            self.tr(u"JSON File missing '{}' entry".format(ex)))
-        except (FatalUserError, ValueError), ex:
+        except (FatalUserError, ValueError) as ex:
             QtWidgets.QMessageBox.critical(self, self.tr("Performance JSON Load"),
                                            self.tr(u"JSON File has Syntax Problems:\n{}".format(ex)))
