@@ -26,6 +26,8 @@
     limitations under the License.
 """
 
+from builtins import str
+
 import logging
 import os
 from datetime import datetime, timedelta
@@ -131,8 +133,8 @@ class SatelliteControlWidget(QtWidgets.QWidget, ui.Ui_SatelliteDockWidget):
         """
         filename = QtGui.QFileDialog.getOpenFileName(
             self, "Open NASA satellite overpass prediction",
-            os.path.dirname(unicode(self.leFile.text())), "(*.*)")
-        filename = filename[0] if USE_PYQT5 else unicode(filename)
+            os.path.dirname(str(self.leFile.text())), "(*.*)")
+        filename = filename[0] if isinstance(filename, list) and USE_PYQT5 else str(filename)
         if not filename:
             return
         self.leFile.setText(filename)
@@ -142,12 +144,12 @@ class SatelliteControlWidget(QtWidgets.QWidget, ui.Ui_SatelliteDockWidget):
         """Load the file specified in leFile and fill the combobox with the
            available track segments.
         """
-        filename = unicode(self.leFile.text())
+        filename = str(self.leFile.text())
         logging.debug("loading satellite overpasses in file '%s'", filename)
 
         try:
             overpass_segments = read_nasa_satellite_prediction(filename)
-        except (IOError, OSError, ValueError), ex:
+        except (IOError, OSError, ValueError) as ex:
             logging.error(u"Problem accessing '%s' file", filename)
             QtWidgets.QMessageBox.critical(self, self.tr("Satellite Overpass Tool"),
                                            self.tr(u"ERROR:\n{}\n{}".format(type(ex), ex)))
