@@ -28,19 +28,18 @@
     limitations under the License.
 """
 
+from builtins import str
+
 import functools
 import logging
 from mslib.utils import config_loader, get_projection_params, save_settings_pickle, load_settings_pickle
 from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
-# related third party imports
 from mslib.msui.mss_qt import QtGui, QtWidgets
-
-# local application imports
 from mslib.msui.mss_qt import ui_topview_window as ui
 from mslib.msui.mss_qt import ui_topview_mapappearance as ui_ma
 from mslib.msui.viewwindows import MSSMplViewWindow
 from mslib.msui import mpl_pathinteractor as mpl_pi
-from mslib.msui import wms_control as wms
+from mslib.msui import wms_control as wc
 from mslib.msui import satellite_dockwidget as sat
 from mslib.msui import remotesensing_dockwidget as rs
 from mslib.msui import kmloverlay_dockwidget as kml
@@ -203,7 +202,7 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         self.cbChangeMapSection.clear()
         predefined_map_sections = config_loader(dataset="predefined_map_sections",
                                                 default=mss_default.predefined_map_sections)
-        items = predefined_map_sections.keys()
+        items = list(predefined_map_sections.keys())
         items.sort()
         self.cbChangeMapSection.addItems(items)
 
@@ -221,7 +220,7 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
             if index == WMS:
                 # Create a new WMSDockWidget.
                 title = "Web Map Service (Top View)"
-                widget = wms.HSecWMSControlWidget(
+                widget = wc.HSecWMSControlWidget(
                     default_WMS=config_loader(dataset="default_WMS", default=mss_default.default_WMS),
                     view=self.mpl.canvas,
                     parent=self,
@@ -245,7 +244,7 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         """Change the current map section to one of the predefined regions.
         """
         # Get the initial projection parameters from the tables in mss_settings.
-        current_map_key = unicode(self.cbChangeMapSection.currentText())
+        current_map_key = str(self.cbChangeMapSection.currentText())
         predefined_map_sections = config_loader(dataset="predefined_map_sections",
                                                 default=mss_default.predefined_map_sections)
         current_map = predefined_map_sections[current_map_key]
@@ -285,28 +284,6 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
             settings = dlg.getSettings()
             self.getView().setMapAppearance(settings)
             self.saveSettings()
-            title = "Top View"
-            if self.docks[WMS]:
-                wms_widget = self.docks[WMS].widget()
-                layer = wms_widget.getLayer()
-                style = wms_widget.getStyle()
-                if style != "":
-                    style_title = wms_widget.get_layer_object(layer).styles[style]["title"]
-                else:
-                    style_title = None
-                level = wms_widget.getLevel()
-                init_time = wms_widget.getInitTime()
-                valid_time = wms_widget.getValidTime()
-                layer_object = wms_widget.get_layer_object(layer)
-                if layer_object is not None:
-                    title = layer_object.title
-                self.mpl.canvas.drawMetadata(title=title,
-                                             init_time=init_time,
-                                             valid_time=valid_time,
-                                             level=level,
-                                             style=style_title)
-            else:
-                self.mpl.canvas.drawMetadata(title=title)
             self.mpl.canvas.waypoints_interactor.redraw_path()
         dlg.destroy()
 
