@@ -63,9 +63,10 @@
     limitations under the License.
 """
 
+from __future__ import division
+
 import logging
 
-# related third party imports
 import numpy as np
 import matplotlib.pyplot as plt
 import mpl_toolkits.axes_grid1.inset_locator
@@ -73,7 +74,6 @@ import matplotlib.colors
 import mpl_toolkits.basemap
 from matplotlib import patheffects
 
-# local application imports
 from mslib.mswms.mpl_hsec import MPLBasemapHorizontalSectionStyle
 from mslib.mswms.utils import Targets, get_style_parameters, get_cbar_label_format
 from mslib.mswms.msschem import MSSChemTargets
@@ -172,7 +172,7 @@ class HS_CloudsStyle_01(MPLBasemapHorizontalSectionStyle):
         elif self.style == "HIGH":
             titlestring = "High cloud cover (0-1)"
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -255,7 +255,7 @@ class HS_MSLPStyle_01(MPLBasemapHorizontalSectionStyle):
 
         titlestring = "Mean sea level pressure (hPa) and surface wind"
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -365,8 +365,8 @@ class HS_SeaIceStyle_01(MPLBasemapHorizontalSectionStyle):
         lonmesh_, latmesh_ = np.meshgrid(self.lons, self.lats)
         if self.style == "PCOL":
             # Shift lat/lon grid for PCOLOR (see comments in HS_EMAC_TracerStyle_SFC_01).
-            lonmesh_ = lonmesh_ - (self.lons[1] - self.lons[0]) / 2.
-            latmesh_ = latmesh_ - (self.lats[1] - self.lats[0]) / 2.
+            lonmesh_ = lonmesh_ - ((self.lons[1] - self.lons[0]) / 2.)
+            latmesh_ = latmesh_ - ((self.lats[1] - self.lats[0]) / 2.)
         lonmesh, latmesh = bm(lonmesh_, latmesh_)
 
         ice = data['sea_ice_area_fraction']
@@ -397,7 +397,7 @@ class HS_SeaIceStyle_01(MPLBasemapHorizontalSectionStyle):
         # Plot title.
         titlestring = "Sea Ice Cover"
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -464,7 +464,7 @@ class HS_TemperatureStyle_ML_01(MPLBasemapHorizontalSectionStyle):
 
         titlestring = "Temperature (degC) at model level %i" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -704,7 +704,7 @@ class HS_TemperatureStyle_PL_01(MPLBasemapHorizontalSectionStyle):
                         linewidths=1, linestyles="solid")
 
         # Plot geopotential height contours.
-        gpm = self.data["geopotential_height"] / 9.81
+        gpm = (self.data["geopotential_height"] / 9.81)
         geop_contours = np.arange(400, 28000, 40)
         cs = bm.contour(lonmesh, latmesh, gpm,
                         geop_contours, colors="black", linewidths=1)
@@ -713,7 +713,7 @@ class HS_TemperatureStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         titlestring = "Temperature (degC) and Geopotential Height (m) at " \
                       "%i hPa" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -805,7 +805,7 @@ class HS_GeopotentialWindStyle_PL(MPLBasemapHorizontalSectionStyle):
                  linewidths=0.5, length=6)
 
         # Plot geopotential height contours.
-        gpm = self.data["geopotential_height"] / 9.81
+        gpm = (self.data["geopotential_height"] / 9.81)
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
@@ -816,7 +816,7 @@ class HS_GeopotentialWindStyle_PL(MPLBasemapHorizontalSectionStyle):
         titlestring = "Geopotential Height (m) and Horizontal Wind (m/s) " \
                       "at %i hPa" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -900,7 +900,7 @@ class HS_RelativeHumidityStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         titlestring = "Relative Humditiy (%%) and Geopotential Height (m) at " \
                       "%i hPa" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = (time_step.days * 86400 + time_step.seconds) // 3600
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -974,7 +974,7 @@ class HS_EQPTStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         #                np.arange(100, 170, 15), colors="yellow", linewidths=1)
 
         # Plot geopotential height contours.
-        gpm = self.data["geopotential_height"] / 9.81
+        gpm = (self.data["geopotential_height"] / 9.81)
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
@@ -984,7 +984,7 @@ class HS_EQPTStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         titlestring = "Equivalent Potential Temperature (degC) and Geopotential Height (m) at " \
                       "%i hPa" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1059,7 +1059,7 @@ class HS_WStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         #                np.arange(100, 170, 15), colors="yellow", linewidths=1)
 
         # Plot geopotential height contours.
-        gpm = self.data["geopotential_height"] / 9.81
+        gpm = (self.data["geopotential_height"] / 9.81)
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
@@ -1069,7 +1069,7 @@ class HS_WStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         titlestring = "Vertical Velocity (cm/s) and Geopotential Height (m) at " \
                       "%i hPa" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1121,7 +1121,7 @@ class HS_DivStyle_PL_01(MPLBasemapHorizontalSectionStyle):
                         linewidths=2, linestyles="solid")
 
         # Plot geopotential height contours.
-        gpm = self.data["geopotential_height"] / 9.81
+        gpm = (self.data["geopotential_height"] / 9.81)
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
@@ -1131,7 +1131,7 @@ class HS_DivStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         titlestring = "Divergence (positive: red, negative: blue) and Geopotential Height (m) at " \
                       "%i hPa" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1168,8 +1168,8 @@ class HS_EMAC_TracerStyle_ML_01(MPLBasemapHorizontalSectionStyle):
 
         # Shift lat/lon grid for PCOLOR (see comments in HS_EMAC_TracerStyle_SFC_01).
         lonmesh_, latmesh_ = np.meshgrid(self.lons, self.lats)
-        lonmesh_ = lonmesh_ - (self.lons[1] - self.lons[0]) / 2.
-        latmesh_ = latmesh_ - (self.lats[1] - self.lats[0]) / 2.
+        lonmesh_ = lonmesh_ - ((self.lons[1] - self.lons[0]) / 2.)
+        latmesh_ = latmesh_ - ((self.lats[1] - self.lats[0]) / 2.)
         lonmesh, latmesh = bm(lonmesh_, latmesh_)
 
         tc = bm.pcolor(lonmesh, latmesh, tracer,
@@ -1198,7 +1198,7 @@ class HS_EMAC_TracerStyle_ML_01(MPLBasemapHorizontalSectionStyle):
 
         titlestring = "EMAC Eyjafjallajokull Tracer (relative) at model level %i" % self.level
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1243,8 +1243,8 @@ class HS_EMAC_TracerStyle_SFC_01(MPLBasemapHorizontalSectionStyle):
         # EMAC's latitudes. The error, however, is small, thus we neglect it
         # here.
         lonmesh_, latmesh_ = np.meshgrid(self.lons, self.lats)
-        lonmesh_ -= (self.lons[1] - self.lons[0]) / 2.
-        latmesh_ -= (self.lats[1] - self.lats[0]) / 2.
+        lonmesh_ -= ((self.lons[1] - self.lons[0]) / 2.)
+        latmesh_ -= ((self.lats[1] - self.lats[0]) / 2.)
         lonmesh, latmesh = bm(lonmesh_, latmesh_)
 
         tc = bm.pcolor(lonmesh, latmesh, tracer,
@@ -1274,7 +1274,7 @@ class HS_EMAC_TracerStyle_SFC_01(MPLBasemapHorizontalSectionStyle):
 
         titlestring = "EMAC Eyjafjallajokull Tracer Total Column Density (kg/m^2)"
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1332,7 +1332,7 @@ class HS_PVTropoStyle_PV_01(MPLBasemapHorizontalSectionStyle):
         if self.style == "PRES":
             filled_contours = np.arange(120, 551, 10)
             thin_contours = np.arange(100, 601, 40)
-            vardata = data["air_pressure"] / 100.
+            vardata = (data["air_pressure"] / 100.)
             label = "Pressure (hPa)"
             fcmap = plt.cm.terrain_r
         elif self.style == "PT":
@@ -1344,7 +1344,7 @@ class HS_PVTropoStyle_PV_01(MPLBasemapHorizontalSectionStyle):
         elif self.style == "GEOP":
             filled_contours = np.arange(5000, 15000, 250)
             thin_contours = np.arange(5000, 15000, 500)
-            vardata = data["geopotential_height"] / 9.81
+            vardata = (data["geopotential_height"] / 9.81)
             label = "Geopotential Height (m)"
             fcmap = plt.cm.terrain
 
@@ -1371,15 +1371,15 @@ class HS_PVTropoStyle_PV_01(MPLBasemapHorizontalSectionStyle):
 
         if self.style == "PRES":
             titlestring = "Dynamical Tropopause Pressure (hPa) at " \
-                          "%i PVU" % (int(self.level) / 1000)
+                          "%i PVU" % (int(self.level) // 1000)
         elif self.style == "PT":
             titlestring = "Dynamical Tropopause Potential Temperature (K) at " \
-                          "%i PVU" % (int(self.level) / 1000)
+                          "%i PVU" % (int(self.level) // 1000)
         elif self.style == "GEOP":
             titlestring = "Dynamical Tropopause Geopotential Height (m) at " \
-                          "%i PVU" % (int(self.level) / 1000)
+                          "%i PVU" % (int(self.level) // 1000)
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = (time_step.days * 86400 + time_step.seconds) // 3600
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1448,7 +1448,7 @@ class HS_VIProbWCB_Style_01(MPLBasemapHorizontalSectionStyle):
 
         titlestring = "Mean sea level pressure (hPa) and total column probability of WCB (0-1)"
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1526,7 +1526,7 @@ class HS_LagrantoTrajStyle_PL_01(MPLBasemapHorizontalSectionStyle):
 
         titlestring = "Cirrus density, insitu red, mix blue, wcb colour (1E-6/km^2/hPa)"
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = ((time_step.days * 86400 + time_step.seconds) // 3600)
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1598,7 +1598,7 @@ class HS_BLH_MSLP_Style_01(MPLBasemapHorizontalSectionStyle):
         # Title
         titlestring = "Boundary layer height (m) and mean sea level pressure (hPa)"
         time_step = self.valid_time - self.init_time
-        time_step_hrs = (time_step.days * 86400 + time_step.seconds) / 3600
+        time_step_hrs = (time_step.days * 86400 + time_step.seconds) // 3600
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
             .format(self.valid_time.strftime('%a %Y-%m-%d %H:%M UTC'),
                     time_step_hrs,
@@ -1777,7 +1777,7 @@ def make_msschem_class(entity, nam, vert, units, scale, add_data=None, add_conto
 
 
 for vert in ["ml", "al", "pl"]:
-    for stdname, props in MSSChemTargets.items():
+    for stdname, props in list(MSSChemTargets.items()):
         name, qty, units, scale = props
         key = "HS_MSSChemStyle_" + vert.upper() + "_" + name + "_" + qty
         globals()[key] = make_msschem_class(stdname, name, vert, units, scale)
@@ -1785,7 +1785,7 @@ for vert in ["ml", "al", "pl"]:
 _pressurelevels = np.linspace(5000, 95000, 19)
 _npressurelevels = len(_pressurelevels)
 for vert in ["ml"]:
-    for stdname, props in MSSChemTargets.items():
+    for stdname, props in list(MSSChemTargets.items()):
         name, qty, units, scale = props
         # ToDo string substitution
         key = "HS_MSSChemStyle_" + vert.upper() + "_" + name + "_" + qty + "_pcontours"
