@@ -29,13 +29,14 @@
     limitations under the License.
 """
 
+from __future__ import division
+
 import matplotlib
 import matplotlib.pyplot as plt
 import mpl_toolkits.axes_grid1.inset_locator
 from matplotlib import patheffects
 import numpy as np
 
-# local application imports
 from mslib.mswms.mpl_vsec import AbstractVerticalSectionStyle
 from mslib.mswms.utils import Targets, get_style_parameters, get_cbar_label_format
 from mslib.mswms.msschem import MSSChemTargets
@@ -62,7 +63,7 @@ class VS_TemperatureStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature if
         it has not been passed as a data field.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -332,7 +333,7 @@ class VS_CloudsStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature if
         it has not been passed as a data field.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -420,7 +421,7 @@ class VS_CloudsWindStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature and
            total horizontal wind speed.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -501,7 +502,7 @@ class VS_RelativeHumdityStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature if
         it has not been passed as a data field. Also computes relative humdity.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -605,7 +606,7 @@ class VS_SpecificHumdityStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature if
         it has not been passed as a data field. Also computes relative humdity.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -718,7 +719,7 @@ class VS_VerticalVelocityStyle_01(AbstractVerticalSectionStyle):
         it has not been passed as a data field. Also computes vertical
         velocity in cm/s.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -823,7 +824,7 @@ class VS_HorizontalVelocityStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature and
            total horizontal wind speed.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -991,44 +992,44 @@ pv_eth_cmap_0 = matplotlib.colors.ListedColormap(pv_cmap_data)
 #           (/170, 255,  60/) )/255
 
 def scale_pvu_to_01(pvu):
-    return (pvu + 2.) / 10.
+    return ((pvu + 2.) / 10.)
 
 
 S = 0.0000000001
 
 _pv_eth_data = (
-    (scale_pvu_to_01(-2.), (142. / 255., 178. / 255., 255. / 255.)),
-    (scale_pvu_to_01(0. - S), (142. / 255., 178. / 255., 255. / 255.)),
+    (scale_pvu_to_01(-2.), ((142. / 255.), (178. / 255.), (255. / 255.))),
+    (scale_pvu_to_01(0. - S), ((142. / 255.), (178. / 255.), (255. / 255.))),
 
-    (scale_pvu_to_01(0.), (181. / 255., 201. / 255., 255. / 255.)),
-    (scale_pvu_to_01(0.2 - S), (181. / 255., 201. / 255., 255. / 255.)),
+    (scale_pvu_to_01(0.), ((181. / 255.), (201. / 255.), (255. / 255.))),
+    (scale_pvu_to_01(0.2 - S), ((181. / 255.), (201. / 255.), (255. / 255.))),
 
-    (scale_pvu_to_01(0.2), (214. / 255., 226. / 255., 237. / 255.)),
-    (scale_pvu_to_01(0.5 - S), (214. / 255., 226. / 255., 237. / 255.)),
+    (scale_pvu_to_01(0.2), ((214. / 255.), (226. / 255.), (237. / 255.))),
+    (scale_pvu_to_01(0.5 - S), ((214. / 255.), (226. / 255.), (237. / 255.))),
 
-    (scale_pvu_to_01(0.5), (242. / 255., 221. / 255., 160. / 255.)),
-    (scale_pvu_to_01(0.8 - S), (242. / 255., 221. / 255., 160. / 255.)),
+    (scale_pvu_to_01(0.5), ((242. / 255.), (221. / 255.), (160. / 255.))),
+    (scale_pvu_to_01(0.8 - S), ((242. / 255.), (221. / 255.), (160. / 255.))),
 
-    (scale_pvu_to_01(0.8), (239. / 255., 193. / 255., 130. / 255.)),
-    (scale_pvu_to_01(1.0 - S), (239. / 255., 193. / 255., 130. / 255.)),
+    (scale_pvu_to_01(0.8), ((239. / 255.), (193. / 255.), (130. / 255.))),
+    (scale_pvu_to_01(1.0 - S), ((239. / 255.), (193. / 255.), (130. / 255.))),
 
-    (scale_pvu_to_01(1.0), (242. / 255., 132. / 255., 68. / 255.)),
-    (scale_pvu_to_01(1.5 - S), (242. / 255., 132. / 255., 68. / 255.)),
+    (scale_pvu_to_01(1.0), ((242. / 255.), (132. / 255.), (68. / 255.))),
+    (scale_pvu_to_01(1.5 - S), ((242. / 255.), (132. / 255.), (68. / 255.))),
 
-    (scale_pvu_to_01(1.5), (220. / 255., 60. / 255., 30. / 255.)),
-    (scale_pvu_to_01(2.0 - S), (220. / 255., 60. / 255., 30. / 255.)),
+    (scale_pvu_to_01(1.5), ((220. / 255.), (60. / 255.), (30. / 255.))),
+    (scale_pvu_to_01(2.0 - S), ((220. / 255.), (60. / 255.), (30. / 255.))),
 
-    (scale_pvu_to_01(2.0), (255. / 255., 120. / 255., 20. / 255.)),
-    (scale_pvu_to_01(3.0 - S), (255. / 255., 120. / 255., 20. / 255.)),
+    (scale_pvu_to_01(2.0), ((255. / 255.), (120. / 255.), (20. / 255.))),
+    (scale_pvu_to_01(3.0 - S), ((255. / 255.), (120. / 255.), (20. / 255.))),
 
-    (scale_pvu_to_01(3.0), (255. / 255., 190. / 255., 20. / 255.)),
-    (scale_pvu_to_01(4.0 - S), (255. / 255., 190. / 255., 20. / 255.)),
+    (scale_pvu_to_01(3.0), ((255. / 255.), (190. / 255.), (20. / 255.))),
+    (scale_pvu_to_01(4.0 - S), ((255. / 255.), (190. / 255.), (20. / 255.))),
 
-    (scale_pvu_to_01(4.0), (255. / 255., 249. / 255., 20. / 255.)),
-    (scale_pvu_to_01(6.0 - S), (255. / 255., 249. / 255., 20. / 255.)),
+    (scale_pvu_to_01(4.0), ((255. / 255.), (249. / 255.), (20. / 255.))),
+    (scale_pvu_to_01(6.0 - S), ((255. / 255.), (249. / 255.), (20. / 255.))),
 
-    (scale_pvu_to_01(6.0), (170. / 255., 255. / 255., 60. / 255.)),
-    (scale_pvu_to_01(8.0), (170. / 255., 255. / 255., 60. / 255.))
+    (scale_pvu_to_01(6.0), ((170. / 255.), (255. / 255.), (60. / 255.))),
+    (scale_pvu_to_01(8.0), ((170. / 255.), (255. / 255.), (60. / 255.)))
 )
 
 pv_eth_cmap_1 = matplotlib.colors.LinearSegmentedColormap.from_list("pv_eth_cmap_1", _pv_eth_data)
@@ -1061,7 +1062,7 @@ class VS_PotentialVorticityStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature and
            total horizontal wind speed.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -1194,7 +1195,7 @@ class VS_ProbabilityOfWCBStyle_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature and
            total horizontal wind speed.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -1365,7 +1366,7 @@ class VS_EMACEyja_Style_01(AbstractVerticalSectionStyle):
         """Computes potential temperature from pressure and temperature if
         it has not been passed as a data field.
         """
-        if 'air_potential_temperature' not in self.data.keys():
+        if 'air_potential_temperature' not in self.data:
             self.data['air_potential_temperature'] = \
                 thermolib.pot_temp(self.data['air_pressure'],
                                    self.data['air_temperature'])
@@ -1456,7 +1457,7 @@ class VS_MSSChemStyle(AbstractVerticalSectionStyle):
         # for altitude level model data, when we don't have air_pressure information, we want to warn users that the
         # vertical section is only an approximation
         if (self.name[-2:] == "al") and\
-                ("p" not in self.driver.data_access.build_filetree().values()[0].values()[0].keys()):
+                ("p" not in list(self.driver.data_access.build_filetree().values())[0].values()[0]):
             self.title = self.title.replace(" al)", " al; WARNING: vert. distribution only approximate!)")
 
     def _prepare_datafields(self):
@@ -1472,7 +1473,7 @@ class VS_MSSChemStyle(AbstractVerticalSectionStyle):
         elif self.name[-2:] == "al":
             # CAMS Regional Ensemble doesn't provide any pressure information, but we want to plot vertical sections
             # anyways, so we do a poor-man's on-the-fly conversion here.
-            if 'air_pressure' not in self.data.keys():
+            if 'air_pressure' not in self.data:
                 self.data["air_pressure"] = np.empty_like(self.data[self.dataname])
                 flightlevel = 3.28083989501 / 100. * self.driver.vert_data[::-self.driver.vert_order, np.newaxis]
                 self.data['air_pressure'][:] = thermolib.flightlevel2pressure_a(flightlevel)
@@ -1593,7 +1594,7 @@ def make_msschem_class(entity, nam, vert, units, scale, add_data=None,
 
 
 for vert in ["ml", "tl", "pl", "al"]:
-    for stdname, props in MSSChemTargets.items():
+    for stdname, props in list(MSSChemTargets.items()):
         name, qty, units, scale = props
         key = "VS_MSSChemStyle_" + vert.upper() + "_" + name + "_" + qty
         globals()[key] = make_msschem_class(stdname, name, vert, units, scale)
