@@ -41,6 +41,12 @@
     limitations under the License.
 """
 
+from future import standard_library
+standard_library.install_aliases()
+
+
+from past.builtins import basestring
+
 import os
 import logging
 from datetime import datetime
@@ -49,12 +55,12 @@ import paste
 import paste.request
 import paste.util.multidict
 import tempfile
-import urlparse
+import urllib.parse
 from chameleon import PageTemplateLoader
 
 try:
     import mss_wms_settings
-except ImportError, ex:
+except ImportError as ex:
     logging.warning(u"Couldn't import mss_wms_settings (ImportError:'{}'), creating dummy config.".format(ex))
 
     class mss_wms_settings(object):
@@ -81,9 +87,10 @@ except ImportError, ex:
         enable_basic_http_authentication = False
         __file__ = None
 
+print(mss_wms_settings.__file__)
 try:
     import mss_wms_auth
-except ImportError, ex:
+except ImportError as ex:
     logging.warning(u"Couldn't import mss_wms_auth (ImportError:'{}'), creating dummy config.".format(ex))
 
     class mss_wms_auth(object):
@@ -111,13 +118,13 @@ class WMSServer(object):
     def __init__(self, data_access_dict):
         self.hsec_layer_registry = {}
         self.hsec_drivers = {}
-        for key in data_access_dict.keys():
+        for key in data_access_dict:
             self.hsec_drivers[key] = mss_plot_driver.HorizontalSectionDriver(
                 data_access_dict[key])
 
         self.vsec_layer_registry = {}
         self.vsec_drivers = {}
-        for key in data_access_dict.keys():
+        for key in data_access_dict:
             self.vsec_drivers[key] = mss_plot_driver.VerticalSectionDriver(
                 data_access_dict[key])
 
@@ -138,8 +145,8 @@ class WMSServer(object):
                           "dataset '{}'".format(layer.name, dataset))
             # Check if the current dataset has already been registered. If
             # not, check whether a suitable driver is available.
-            if dataset not in self.hsec_layer_registry.keys():
-                if dataset in self.hsec_drivers.keys():
+            if dataset not in self.hsec_layer_registry:
+                if dataset in self.hsec_drivers:
                     self.hsec_layer_registry[dataset] = {}
                 else:
                     raise ValueError(u"dataset '{}' not available".format(dataset))
@@ -159,8 +166,8 @@ class WMSServer(object):
             logging.debug(u"registering vertical section layer '{}' with dataset '{}'".format(layer.name, dataset))
             # Check if the current dataset has already been registered. If
             # not, check whether a suitable driver is available.
-            if dataset not in self.vsec_layer_registry.keys():
-                if dataset in self.vsec_drivers.keys():
+            if dataset not in self.vsec_layer_registry:
+                if dataset in self.vsec_drivers:
                     self.vsec_layer_registry[dataset] = {}
                 else:
                     raise ValueError(u"dataset '{}' not available".format(dataset))
@@ -171,7 +178,7 @@ class WMSServer(object):
         """Returns True if the given parameter is an XML that contains
            a service exception.
         """
-        if isinstance(var, basestring) and var.find("<ServiceException") > 1:
+        if isinstance(var, basestring) and var.find(b"<ServiceException") > 1:
             return True
         return False
 
@@ -196,8 +203,8 @@ class WMSServer(object):
 
         # Horizontal Layers
         hsec_layers = []
-        for dataset in self.hsec_layer_registry.keys():
-            for layer in self.hsec_layer_registry[dataset].values():
+        for dataset in self.hsec_layer_registry:
+            for layer in list(self.hsec_layer_registry[dataset].values()):
                 if layer.uses_time_dimensions() and len(layer.get_init_times()) == 0:
                     logging.error("layer %s/%s has no init times!", layer, dataset)
                     continue
@@ -208,8 +215,8 @@ class WMSServer(object):
 
         # Vertical Layers
         vsec_layers = []
-        for dataset in self.vsec_layer_registry.keys():
-            for layer in self.vsec_layer_registry[dataset].values():
+        for dataset in self.vsec_layer_registry:
+            for layer in list(self.vsec_layer_registry[dataset].values()):
                 if layer.uses_time_dimensions() and len(layer.get_init_times()) == 0:
                     logging.error("layer %s/%s has no init times!", layer, dataset)
                     continue
@@ -345,8 +352,8 @@ class WMSServer(object):
         if mode == "GetMap":
 
             # Check requested layer.
-            if (dataset not in self.hsec_layer_registry.keys()) or \
-               (layer not in self.hsec_layer_registry[dataset].keys()):
+            if (dataset not in self.hsec_layer_registry) or \
+               (layer not in self.hsec_layer_registry[dataset]):
                 msg = u"Invalid LAYER '{}.{}' requested".format(dataset, layer)
                 logging.error(msg)
                 return self.service_exception(code="LayerNotDefined", text=msg)
@@ -430,8 +437,8 @@ class WMSServer(object):
             logging.debug(u"VSEC PATH: {}".format(path))
 
             # Check requested layers.
-            if (dataset not in self.vsec_layer_registry.keys()) or \
-                    (layer not in self.vsec_layer_registry[dataset].keys()):
+            if (dataset not in self.vsec_layer_registry) or \
+                    (layer not in self.vsec_layer_registry[dataset]):
                 msg = u"Invalid LAYER '{}.{}' requested".format(dataset, layer)
                 return self.service_exception(code="LayerNotDefined", text=msg)
 
@@ -507,31 +514,34 @@ def application(environ, start_response):
 
         # Processing
         request = str(query.get('request'))
-        return_data = ""
+        output = ""
         return_format = 'text/plain'
 
         url = paste.request.construct_url(environ)
-        server_url = urlparse.urljoin(url, urlparse.urlparse(url).path)
+        server_url = urllib.parse.urljoin(url, urllib.parse.urlparse(url).path)
 
-        if url in cache.keys():
-            return_format, return_data = cache[url]
+        if url in cache:
+            return_format, output = cache[url]
         else:
             if request.lower() == 'getcapabilities':
                 return_format = 'text/xml'
                 return_data = app.get_capabilities(server_url)
+                output = str(return_data).encode('utf-8')
             elif request.lower() in ['getmap', 'getvsec']:
                 return_data, return_format = app.produce_plot(environ, request)
+                # ToDo refactor
                 if not app.is_service_exception(return_data):
                     return_format = return_format.lower()  # MAYBE TO BE DELETED
+                    output = return_data
                 else:
                     return_format = "text/xml"
+                    output = str(return_data).encode('utf-8')
 
                 # Saving the result in a cache
-                cache[url] = (return_format, return_data)
+                cache[url] = (return_format, output)
 
         # Preparing the Response
         status = '200 OK'
-        output = str(return_data)
         response_headers = [('Content-type', return_format), ('Content-Length', str(len(output)))]
         start_response(status, response_headers)
 
