@@ -29,7 +29,6 @@
 import glob
 import re
 
-# related third party imports
 import netCDF4
 
 
@@ -67,7 +66,7 @@ def identify_variable(ncfile, standard_name, check=False):
 
     """
 
-    for var_name, variable in ncfile.variables.items():
+    for var_name, variable in list(ncfile.variables.items()):
         if "standard_name" in variable.ncattrs() and variable.standard_name == standard_name:
             return var_name, variable
     if check:
@@ -287,7 +286,7 @@ class MFDatasetCommonDims(netCDF4.MFDataset):
     <http://netcdf4-python.googlecode.com/>} library by Jeffrey Whitaker.
     """
 
-    def __init__(self, files, exclude=[], skipDimCheck=[],
+    def __init__(self, files, exclude=None, skipDimCheck=None,
                  requireDimNum=False):
         """
         Open a Dataset spanning multiple files sharing common dimensions but
@@ -326,6 +325,9 @@ class MFDatasetCommonDims(netCDF4.MFDataset):
         """
         # Open the master file in the base class, so that the CDFMF instance
         # can be used like a CDF instance.
+
+        exclude = exclude or []
+        skipDimCheck = skipDimCheck or []
         if isinstance(files, str):
             files = sorted(glob.glob(files))
 
@@ -335,11 +337,10 @@ class MFDatasetCommonDims(netCDF4.MFDataset):
         # calling methods of the CDFMF subclass when querying the master file.
         cdfm = netCDF4.Dataset(master)
         # copy attributes from master.
-        for name, value in cdfm.__dict__.items():
-            self.__dict__[name] = value
+        self.__dict__.update(cdfm.__dict__)
 
         # Get names of master dimensions.
-        masterDims = cdfm.dimensions.keys()
+        masterDims = list(cdfm.dimensions.keys())
 
         # Create the following:
         #   cdf       list of Dataset instances
@@ -348,7 +349,7 @@ class MFDatasetCommonDims(netCDF4.MFDataset):
         self._cdf = cdf  # Store this now, because dim() method needs it
         cdfVar = {}
         cdfOrigin = {}
-        for vName, v in cdfm.variables.items():
+        for vName, v in list(cdfm.variables.items()):
             if vName in exclude:
                 continue
             cdfVar[vName] = v
@@ -362,7 +363,7 @@ class MFDatasetCommonDims(netCDF4.MFDataset):
         for f in files[1:]:
             part = netCDF4.Dataset(f)
             # Make sure dimension of new dataset are contained in the master.
-            for dimName in part.dimensions.keys():
+            for dimName in part.dimensions:
                 # (..except those that shall not be tested..)
                 if dimName not in skipDimCheck:
                     if dimName not in masterDims:
@@ -377,7 +378,7 @@ class MFDatasetCommonDims(netCDF4.MFDataset):
                     raise IOError(u"number of dimensions not consistent in master "
                                   u"'{}' and '{}'".format(master, f))
 
-            for vName, v in part.variables.items():
+            for vName, v in list(part.variables.items()):
                 # Exclude dimension variables.
                 if (vName in exclude) or (vName in masterDims):
                     continue
